<?php
/**
 * File information.
 * Created at: 21:24 - 15/05/2020
 */
namespace KLM\App\Http\Controllers;

use KLM\Utils;

/**
 * Class MetaBoxesController.
 *
 * @package KLM\App\Http\Controllers
 */
class MetaBoxesController {

	/**
	 * InitController constructor.
	 */
	public function __construct() {}

	/**
	 * Run class.
	 */
	public function run() {

		// Add meta boxes for post type is "kdn_link_mask".
		$this->addMetaBoxes_kdn_link_mask();

	}

	/**
	 * Add meta boxes for post type is "kdn_link_mask".
	 */
	public function addMetaBoxes_kdn_link_mask() {

		// Add meta box "kdn_link_mask_settings".
		add_meta_box(
			'kdn_link_mask_settings',
			_klm('Settings'),
			[$this, 'addMetaBoxesCallback_kdn_link_mask'],
			'kdn_link_mask',
			'normal',
			'high',
			['view' => 'settings']
		);

		// Add meta box "kdn_link_mask_import_export".
		add_meta_box(
			'kdn_link_mask_import_export',
			_klm('Import/Export'),
			[$this, 'addMetaBoxesCallback_kdn_link_mask'],
			'kdn_link_mask',
			'normal',
			'low',
			['view' => 'import_export']
		);

	}

	/**
	 * Add meta boxes callback for post type is "kdn_link_mask".
	 *
	 * @param	\WP_Post	$post				The post object.
	 * @param	array		$metaboxSettings	The meta box settings.
	 */
	public function addMetaBoxesCallback_kdn_link_mask($post, $metaboxSettings) {

		// Get view defined.
		$view = $metaboxSettings['args']['view'] ?? '';

		// Get settings.
		$settings = get_post_meta($post->ID, '_klm_settings', true);

		// Meta box "kdn_link_mask_settings".
		if ($view == 'settings') {

			// Display meta box content.
			echo Utils::view('meta_boxes.kdn_link_mask.settings.main')
						->with([
							'post'		=> $post,
							'settings'	=> $settings
						])
						->render();

		}
		// Meta box "kdn_link_mask_import_export".
		elseif ($view == 'import_export') {

			// Encode settings.
			$exportCode = base64_encode(json_encode($settings));

			// Display meta box content.
			echo Utils::view('meta_boxes.kdn_link_mask.settings.import-export')
						->with([
							'exportCode' => $exportCode
						])
						->render();

		}

	}

}