<?php
/**
 * File information.
 * Created at: 16:26 - 17/05/2020
 */
namespace KLM\App\Http\Controllers;
use GuzzleHttp;
use KLM\Constants;

/**
 * Class RestAPIController.
 *
 * @package KLM\App\Http\Controllers
 */
class RestAPIController {

	/**
	 * RestAPIController constructor.
	 */
	public function __construct() {
	}

	/**
	 * Initialize routes.
	 */
	public function run() {

		// Register rest route "klm/request".
		$this->registerRestRoute_request();

	}

	/**
	 * Register rest route "klm/request".
	 */
	public function registerRestRoute_request() {
		register_rest_route( 'klm', '/request', [
			'methods'	=> 'GET',
			'callback'	=> [$this, 'registerRestRouteCallback_request'],
		]);
	}

	/**
	 * Rest route "klm/request" callback.
	 *
	 * @param	\WP_REST_Request    $request
	 *
	 * @return	array|bool|mixed|\Psr\Http\Message\ResponseInterface
	 *
	 * @throws	\GuzzleHttp\Exception\GuzzleException
	 */
	public function registerRestRouteCallback_request($request) {

		// Get all parameters from URL request.
		$allParams	= $request->get_params();

		// Define parameters.
		$targetURL	= $allParams['url'] ?? '';
		$maskId		= $allParams['maskId'] ?? '';

		// If do not have target URL or mask ID, stop.
		if (!$targetURL || !$maskId) return false;

		// Get link mask settings.
		$settings = get_post_meta($maskId, '_klm_settings', true);

		/**
		 * Prepare client and request configs.
		 */

		$settingBaseURI			= $settings['_klm_base_uri'] ?? '';
		$settingMethod			= $settings['_klm_method'] ?? Constants::$defaultMethod;
		$settingHeaders			= $settings['_klm_headers'] ?? [];
		$headers				= [];
		foreach ($settingHeaders as $settingHeader) {
			$headers[$settingHeader['key']] = $settingHeader['value'];
		}
		$settingAutoContentType = $settings['_klm_auto_content_type'] ?? false;

		/**
		 * Create client.
		 */

		$client = new GuzzleHttp\Client([
			'base_uri'	=> $settingBaseURI,
		]);

		/**
		 * Try to request or catch an error.
		 */

		try {

			// Request to target URL.
			$response = $client->request($settingMethod, $targetURL, [
				'headers'	=> $headers,
				'verify'	=> false,
			]);

			// If auto "Content-Type" header is "on".
			if ($settingAutoContentType) {

				// Get content type after request successfully.
				$contentType = $response->getHeaderLine('Content-Type');

				// Set the header "Content-Type" for display screen.
				header('Content-Type: ' . $contentType);

				// Print response body.
				echo $response->getBody();

			}
			// Otherwise, return response body.
			else {

				// Prepare response.
				$response = [
					'success'		=> true,
					'data'			=> [
						'bodyContent'	=> $response->getBody()->getContents()
					],
					'message'		=> 'Success',
					'error_code'	=> 0
				];

				// Return response.
				return $response;

			}

		}
		catch (GuzzleHttp\Exception\GuzzleException $e) {

			// Prepare response.
			$response = [
				'success'		=> false,
				'data'			=> [],
				'message'		=> $e->getMessage(),
				'error_code'	=> $e->getCode()
			];

			// Return response.
			return $response;

		}

	}

}